import { EventEmitter, Component, Input, ViewChild, ViewChildren, Output, HostListener, NgModule } from '@angular/core';
import { FontAwesomeModule } from '@fortawesome/angular-fontawesome';
import { BrowserModule } from '@angular/platform-browser';
import { CommonModule } from '@angular/common';
import { RouterModule } from '@angular/router';

class DrsNavbarComponent {
    constructor() {
        // Dropdown showed
        this.dropDownShowing = -1;
        this.paletteClass = '';
        this.isOpen = false;
        // Event emitter
        this.onDropdownClick = new EventEmitter();
        this.onDropDownLinkClick = new EventEmitter();
    }
    /*  LifeCycle Hooks
    ============================================================================================== */
    ngOnInit() {
        this.initializeConfiguration();
    }
    ngOnChanges() {
        this.initializeConfiguration();
    }
    /* Navbar Style/Open & Close Method
    ======================================================================================= */
    clickout(event) {
        if (!this.links.some(x => x.nativeElement.contains(event.target)) && document.body.clientWidth > 900) {
            this.clearDropdown();
        }
    }
    navbarChanges(event) {
        var _a;
        if (document.documentElement.scrollTop > 50) {
            this.navbar.nativeElement.classList.add("slim-nvb");
            this.navbar.nativeElement.classList.remove("show");
            (_a = this.navbar.nativeElement.querySelector(".nvb-close")) === null || _a === void 0 ? void 0 : _a.classList.remove("show");
            this.closeNvb();
        }
        else {
            this.navbar.nativeElement.classList.remove("slim-nvb");
        }
    }
    // open navbar when device mode
    toggleNavOnButtonClick() {
        var _a;
        this.navbar.nativeElement.classList.toggle("show");
        (_a = this.navbar.nativeElement.querySelector(".nvb-close")) === null || _a === void 0 ? void 0 : _a.classList.toggle("show");
        this.isOpen = !this.isOpen;
    }
    // close when clicking a route
    closeNvb() {
        var _a;
        this.navbar.nativeElement.classList.remove("show");
        (_a = this.navbar.nativeElement.querySelector(".nvb-close")) === null || _a === void 0 ? void 0 : _a.classList.remove("show");
        this.clearDropdown();
        this.isOpen = false;
    }
    /* DropDown Method
    ====================================================================================*/
    // Set All NavbarConfiguration
    initializeConfiguration() {
        var _a;
        /* Set Palette */
        if (this.navbarConfiguration.palette) {
            this.paletteClass = (_a = this.navbarConfiguration.palette) === null || _a === void 0 ? void 0 : _a.valueOf();
        }
    }
    /* Show dropdown methopd for desktop device */
    showDesktopDropdown(key) {
        this.dropDownShowing = this.dropDownShowing === key ? -1 : key;
    }
    /* Show dropdown methopd for phone device */
    showPhoneDropdown(key) {
        this.dropDownShowing = this.dropDownShowing === key ? -1 : key;
    }
    clearDropdown() {
        this.dropDownShowing = -1;
    }
    /* Event Emitters Method
    ==================================================================================*/
    /** Link emitter */
    emitLinkClick(name) {
        this.onDropDownLinkClick.emit(name);
        this.clearDropdown();
        this.closeNvb();
    }
    /** Dropdown emitter */
    emitDropdownClick(type) {
        this.onDropdownClick.emit(type);
        this.clearDropdown();
        this.closeNvb();
    }
}
DrsNavbarComponent.decorators = [
    { type: Component, args: [{
                selector: 'drs-navbar',
                template: "<div class=\"nvb\" [ngClass]=\"paletteClass\" #drsNavbar>\r\n  <!-- Men\u00F9 in Desktop Size -->\r\n  <!-- ========================================== -->\r\n  <div class=\"nvb-open\">\r\n    <div class=\"nvb-icon-box\">\r\n        <img [src]=\"navbarConfiguration.logoSrc\" class=\"spc-logo\" alt=\"logo\" [routerLink]=\"['/']\" *ngIf=\"navbarConfiguration.logoSrc\">\r\n    </div>\r\n    <div class=\"nvb-ul\" [ngClass]=\"paletteClass\">\r\n      <div class=\"nvb-items-wrapper\" #lnks *ngFor=\"let link of navbarConfiguration.links; let i = index\">\r\n        <div class=\"nvb-items\" (click)=\"emitLinkClick(link.name)\" *ngIf=\"link.route\" [routerLink]=\"link.route\" [routerLinkActive]=\"'active'\" [routerLinkActiveOptions]=\"{exact: true}\">\r\n          <div class=\"nvb-link\" [ngClass]=\"paletteClass\">\r\n            <ng-template *ngTemplateOutlet=\"linkTemplate; context: { $implicit: link }\"></ng-template>\r\n          </div>\r\n        </div>\r\n        <div class=\"big-chevron\" (click)=\"showDesktopDropdown(i)\" *ngIf=\"link.dropDownList\">&#8595;</div>\r\n        <!-- Dropdown in Desktop Size -->\r\n        <div class=\"dropdown\" *ngIf=\"link.dropDownList && dropDownShowing === i\">\r\n          <p *ngFor=\"let item of link.dropDownList\" (click)=\"emitDropdownClick(item.key!)\">\r\n            <ng-template *ngTemplateOutlet=\"dropdownTemplate; context: { $implicit: item }\"></ng-template>\r\n          </p>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n  <!-- ========================================== -->\r\n\r\n\r\n  <!-- Hamburger men\u00F9 in mobile phone -->\r\n  <!-- ========================================== -->\r\n  <div class=\"hamburger-menu\" [ngClass]=\"paletteClass\" (click)=\"toggleNavOnButtonClick()\">\r\n    <ng-container *ngIf=\"buttonTemplate; else defaultButtons\">\r\n      <ng-template *ngTemplateOutlet=\"isOpen ? buttonTemplate.openedDropdown : buttonTemplate.closedDropdown\"></ng-template>\r\n    </ng-container>\r\n    <ng-template #defaultButtons>\r\n      <ng-container *ngIf=\"isOpen\"> &#10006;</ng-container>\r\n      <ng-container *ngIf=\"!isOpen\"> &#10022;</ng-container>\r\n    </ng-template>\r\n  </div>\r\n  <!-- ========================================== -->\r\n  <!-- Navbar in Mobile Phone -->\r\n  <div class=\"nvb-close\">\r\n    <div class=\"nvb-box-wrapper\" [ngClass]=\"paletteClass\" *ngFor=\"let link of navbarConfiguration.links; let i = index\" [routerLinkActive]=\"link.route ? 'active' : ''\" [routerLinkActiveOptions]=\"{exact: true}\">\r\n      <div class=\"nvb-box\">\r\n        <!-- Main Link -->\r\n        <div class=\"main-link\" [routerLink]=\"link.route\" (click)=\"emitLinkClick(link.name)\">\r\n          <div >\r\n            <ng-template *ngTemplateOutlet=\"linkTemplate; context: { $implicit: link }\"></ng-template>\r\n          </div>\r\n        </div>\r\n      </div>\r\n      <!-- DropDown in Mobile Phone -->\r\n        <div class=\"sub-list\" *ngIf=\"link.dropDownList && dropDownShowing === i\">\r\n          <p class=\"sub-link\" *ngFor=\"let item of link.dropDownList\" (click)=\"emitDropdownClick(item.key!)\">{{item.name}}</p>\r\n        </div>\r\n      <div class=\"chevron\" (click)=\"showPhoneDropdown(i)\" *ngIf=\"link.dropDownList\">\r\n        O\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n",
                styles: ["@import\"https://fonts.googleapis.com/css2?family=Montserrat:wght@300;400;500;600;700&display=swap\";.nvb{width:100%;height:4.5rem;position:fixed;top:0;left:50%;transform:translate(-50%);font-family:\"Montserrat\",sans-serif;font-weight:600;color:#222f3e;z-index:2;background-color:#e4e6ec;border-bottom:5px solid #222f3e;padding:0 2.5%;transition:all .2s;z-index:9999999}.nvb-open{height:4.5rem;display:flex;justify-content:space-between}.spc-logo{height:90%;width:auto;transition:all .2s;position:relative}.nvb-icon-box{max-width:300px;width:100px;height:100%;display:flex;justify-content:center;align-items:center}.nvb-ul{max-width:100%;min-width:50vw;height:100%;display:flex;font-size:1.2rem}.nvb-items-wrapper{width:100%;height:100%;position:relative;display:flex;align-items:center;justify-content:center;flex-direction:row;padding:0 1rem}.nvb-link,.big-chevron{cursor:pointer;text-align:center}.nvb-items:focus{border:none;outline:none}.nvb-items:focus:not(.nvb-items.active) .nvb-link{color:#222f3e}.nvb-ul .active:before{position:absolute;width:100%;height:100%;left:0;bottom:0;background-color:#222f3e83;z-index:-1;content:\"\"}.dropdown{position:absolute;width:100%;background-color:#e4e6ec;top:4.83rem;border-radius:0 0 .5rem .5rem;box-shadow:2px 2px 5px 1px #b3b3b3b4;transition:all .2s;font-size:.9rem;padding:0 1rem;box-sizing:border-box;max-height:12.3125rem;overflow-y:scroll}.dropdown::-webkit-scrollbar{width:0px}.dropdown p{width:100%;cursor:pointer;margin:1.2rem 0}.dropdown p:hover{opacity:.8}.big-chevron{z-index:10;cursor:pointer;font-size:1rem;display:flex;align-items:center;justify-content:center;margin-left:1rem}.nvb-close{display:none;flex-direction:row;flex-wrap:wrap;align-items:flex-start;justify-content:flex-start;width:100%;max-height:100%;overflow-y:scroll;overflow-x:hidden}.nvb-close::-webkit-scrollbar{width:0px!important}.hamburger-menu{display:none;cursor:pointer;background-color:#222f3e83;border-radius:8px;transition:all .2s}.nvb-box-wrapper{cursor:pointer;margin:5px;width:100%;border-radius:8px;box-shadow:2px 2px 5px 1px #b3b3b3b4;letter-spacing:3px;transition:all .2s;position:relative}.nvb-box{padding:0 .5rem;border-radius:.5rem;height:60px;display:flex;align-items:center;font-size:1.3rem}.nvb-box-wrapper.active{background-color:#222f3e;color:#fff}.sub-list{display:flex;flex-direction:column;box-sizing:border-box;padding:0 1rem 1rem 1.5rem;max-height:9rem;overflow-y:scroll;scrollbar-width:none}.sub-list::-webkit-scrollbar{width:0rem}.sub-link{cursor:pointer;font-size:1rem;margin:.75rem 0}.sub-link:hover{opacity:.8}.chevron{z-index:9999;position:absolute;right:1.5rem;top:1.1rem;cursor:pointer}.main-link{width:90%}@media screen and (max-width: 900px){.nvb-link,.round-icon{font-size:1.4rem}.nvb-ul{width:50%}.nvb{justify-content:flex-start}.nvb.show{height:100%!important}.nvb-ul{display:none}.nvb-close.show{display:flex}.nvb-close.show .nvb-box{animation:fadeIn 1.5s}.hamburger-menu{display:flex;align-items:center;justify-content:center;position:absolute;top:1rem;right:3%;height:30px;width:30px}}@media screen and (max-width: 765px){.nvb{padding:0;height:4rem}.nvb-open{height:4rem}.nvb-icon-box{max-width:11.25rem;width:3.75rem}.nvb-ul{width:80%}.nvb-link,.round-icon{font-size:1rem}}@keyframes fadeIn{0%{opacity:0}to{opacity:100}}\n", ".nvb.red-palette{border-bottom:5px solid #e2373f}.nvb-ul.red-palette .active:before{background-color:#e2373f45}.nvb-box-wrapper.red-palette.active{background-color:#e2373f}.hamburger-menu.red-palette{background-color:#e2373f45}.nvb.violet-palette{border-bottom:5px solid #9b59b6}.nvb-ul.violet-palette .active:before{background-color:#9b59b645}.nvb-box-wrapper.violet-palette.active{background-color:#9b59b6}.hamburger-menu.violet-palette{background-color:#9b59b645}.nvb.green-palette{border-bottom:5px solid #16a085}.nvb-ul.green-palette .active:before{background-color:#16a08545}.nvb-box-wrapper.green-palette.active{background-color:#16a085}.hamburger-menu.green-palette{background-color:#16a08545}.nvb.sky-palette{border-bottom:5px solid #2980b9}.nvb-ul.sky-palette .active:before{background-color:#2980b945}.nvb-box-wrapper.sky-palette.active{background-color:#2980b9}.hamburger-menu.sky-palette{background-color:#2980b945}.nvb.orange-palette{border-bottom:5px solid #e67e22}.nvb-ul.orange-palette .active:before{background-color:#e67e22a6}.nvb-box-wrapper.orange-palette.active{background-color:#e67e22}.hamburger-menu.orange-palette{background-color:#e67e22a6}\n"]
            },] }
];
DrsNavbarComponent.ctorParameters = () => [];
DrsNavbarComponent.propDecorators = {
    linkTemplate: [{ type: Input }],
    dropdownTemplate: [{ type: Input }],
    buttonTemplate: [{ type: Input }],
    navbarConfiguration: [{ type: Input }],
    navbar: [{ type: ViewChild, args: ["drsNavbar",] }],
    links: [{ type: ViewChildren, args: ["lnks",] }],
    onDropdownClick: [{ type: Output }],
    onDropDownLinkClick: [{ type: Output }],
    clickout: [{ type: HostListener, args: ['document:click', ['$event'],] }],
    navbarChanges: [{ type: HostListener, args: ['window:scroll', ['$event'],] }]
};
class DrsNavbarConfiguration {
}
class DrsNavbarLinks {
}
class DrsNavbarDropdown {
}
class ButtonTemplate {
}
var DrsNavbarPalette;
(function (DrsNavbarPalette) {
    DrsNavbarPalette["DarkPalette"] = "dark-palette";
    DrsNavbarPalette["RedPalette"] = "red-palette";
    DrsNavbarPalette["VioletPalette"] = "violet-palette";
    DrsNavbarPalette["GreenPalette"] = "green-palette";
    DrsNavbarPalette["SkyPalette"] = "sky-palette";
    DrsNavbarPalette["OrangePalette"] = "orange-palette";
})(DrsNavbarPalette || (DrsNavbarPalette = {}));

class DrsNavbarModule {
}
DrsNavbarModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    DrsNavbarComponent
                ],
                imports: [
                    BrowserModule,
                    CommonModule,
                    RouterModule,
                    FontAwesomeModule
                ],
                exports: [
                    DrsNavbarComponent
                ]
            },] }
];

/*
 * Public API Surface of drs-navbar
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ButtonTemplate, DrsNavbarComponent, DrsNavbarConfiguration, DrsNavbarDropdown, DrsNavbarLinks, DrsNavbarModule, DrsNavbarPalette };
//# sourceMappingURL=drs-navbar.js.map
